@@ -14,12 +14,13 @@ class BonusDisciplineWindow : public QDialog
     Q_OBJECT
 
 public:
-    explicit BonusDisciplineWindow(QWidget *parent = 0, int serie=Book::Kai, Player* player=0);
+    explicit BonusDisciplineWindow(QWidget *parent = 0, Book* book=0, Player* player=0);
     ~BonusDisciplineWindow();
 
 private:
     Ui::BonusDisciplineWindow *ui;
 
+    Book* m_Book;
     RandomNumberPicker* m_RandomPicker;
     int m_Serie;
     Player* m_Player;
@@ -35,6 +36,7 @@ private slots:
     void ChooseSlot();
     void RandomSlot();
     void GetRandomSlot(int);
+    void DiscipleLinkSlot(QString link);
 };
 
 #endif // BONUSDISCIPLINEWINDOW_H
