@@ -1014,7 +1014,7 @@ void BookWindow::AboutSlot()
 
 void BookWindow::AddBonusDiscipline()
 {
-    BonusDisciplineWindow* dlg = new BonusDisciplineWindow(this, m_Book->GetSerie(), m_Player);
+    BonusDisciplineWindow* dlg = new BonusDisciplineWindow(this, m_Book, m_Player);
     while (dlg->exec() != QDialog::Accepted	){}
     delete dlg;
 }
