@@ -55,6 +55,13 @@ void Item::Use(QScriptEngine* engine, QScriptValue* functions)
     }
 }
 
+bool Item::GetCanBeEquipped()
+{
+    if (!HasProperty("CanBeEquipped"))
+        return true;
+    return GetBoolProperty("CanBeEquipped");
+}
+
 void Item::SetCanBeEquipped(bool value)
 {
     if (!value && GetIsEquipped())
