@@ -31,6 +31,9 @@ PlayerCreationWindow::PlayerCreationWindow(QWidget *parent) :
     ui->lblItem->setPalette(secondaryPalette);
 #endif
 
+    m_Book = new Book(this);
+    m_Book->Load(Books::GetBookFilename(1));
+
     m_RandomPicker = new RandomNumberPicker(this, ui->lblDice);
     connect(m_RandomPicker, SIGNAL(Random(int)), SLOT(RandomSlot(int)));
 
@@ -53,6 +56,13 @@ PlayerCreationWindow::PlayerCreationWindow(QWidget *parent) :
     EnableButtons(true);
     ShowData();
 
+    QList<QLabel*> labels;
+    labels << ui->lblWeaponskill << ui->label_5 << ui->label_6 << ui->label_8
+           << ui->label_9 << ui->label_10 << ui->label_12 << ui->label_13
+           << ui->label_14 << ui->label_15;
+    foreach (QLabel* lbl, labels)
+        connect(lbl, SIGNAL(linkActivated(QString)), this, SLOT(DiscipleLinkSlot(QString)));
+
     connect(ui->actionRules, SIGNAL(triggered()), this, SLOT(RulesSlot()));
 
     connect(ui->pbnCombatSkill, SIGNAL(clicked()), this, SLOT(CombatSkillSlot()));
@@ -518,3 +528,10 @@ void PlayerCreationWindow::CheckDone()
     else
         ui->pbnDone->setEnabled(false);
 }
+
+void PlayerCreationWindow::DiscipleLinkSlot(QString link)
+{
+    RulesWindow* dlg = new RulesWindow(this, m_Book->BaseDirectory);
+    dlg->show();
+    dlg->ScrollToAnchor(link);
+}
