@@ -6,6 +6,8 @@
 #endif
 #include <QFile>
 #include "commonstatic.h"
+#include <QDebug>
+#include <QWebFrame>
 
 RulesWindow::RulesWindow(QWidget *parent, QString bookDirectory) :
     QMainWindow(parent),
@@ -60,3 +62,8 @@ RulesWindow::~RulesWindow()
 {
     delete ui;
 }
+
+void RulesWindow::ScrollToAnchor(QString anchor)
+{
+    ui->webView->page()->mainFrame()->evaluateJavaScript(QString("window.location.hash=\"%1\";").arg(anchor));
+}
