@@ -6,6 +6,7 @@
 #include <QMaemo5Style>
 #endif
 #include "commonstatic.h"
+#include "ruleswindow.h"
 
 StatusWindow::StatusWindow(QWidget *parent, int serie, Player* player, Section* section, QScriptEngine* engine, QScriptValue* functions) :
     QMainWindow(parent),
@@ -218,8 +219,11 @@ void StatusWindow::ShowData()
         ui->layKaiDisciplines->addWidget(lbl, row, 0);
 
         lbl = new QLabel(this);
-        lbl->setText(d->Description());
+        lbl->setText(QString("<a href=\"%1\">%2</a>").arg(d->Name.toLower().replace(" ", ""))
+                                                     .arg(d->Description()));
         ui->layKaiDisciplines->addWidget(lbl, row, 1);
+        connect(lbl, SIGNAL(linkActivated(QString)), this, SLOT(DiscipleLinkSlot(QString)));
+
         lbl = new QLabel(this);
         lbl->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
         lbl->setText(Player::GetRankDescription(row + 1));
@@ -571,3 +575,11 @@ void StatusWindow::ClearLayout(QLayout* layout)
         delete child;
     }
 }
+
+void StatusWindow::DiscipleLinkSlot(QString link)
+{
+    Book* book = (Book*)m_Section->parent();
+    RulesWindow* dlg = new RulesWindow(this, book->BaseDirectory);
+    dlg->show();
+    dlg->ScrollToAnchor(link);
+}
